@@ -15,18 +15,20 @@
  */
 package org.drools.workbench.screens.guided.dtable.client;
 
+import javax.annotation.PostConstruct;
+
 import org.drools.workbench.screens.guided.dtable.client.resources.GuidedDecisionTableResources;
-import org.jboss.errai.ioc.client.api.AfterInitialization;
+import org.drools.workbench.services.verifier.api.client.resources.AnalyzerResources;
 import org.jboss.errai.ioc.client.api.EntryPoint;
-import org.drools.workbench.screens.guided.dtable.client.resources.GuidedDecisionTableResources;
+import org.jboss.errai.ui.shared.api.annotations.Bundle;
 
 @EntryPoint
+@Bundle("resources/i18n/GuidedDecisionTableErraiConstants.properties")
 public class GuidedDecisionTableEditorEntryPoint {
 
-    @AfterInitialization
+    @PostConstruct
     public void startApp() {
         GuidedDecisionTableResources.INSTANCE.css().ensureInjected();
-        GuidedDecisionTableResources.INSTANCE.analysisCss().ensureInjected();
+        AnalyzerResources.INSTANCE.analysisCss().ensureInjected();
     }
-
-}
\ No newline at end of file
+}
